@@ -274,9 +274,9 @@ class ManyToManyColumn(DatatableColumn):
 
     def setup_results(self, request, all_results):
         if self.reverse:
-            tags = self.related_model.objects.values_list(self.field_id, 'id')
+            tags = self.related_model.objects.values_list(self.field_id, 'pk')
         else:
-            tags = self.model.objects.values_list('id', self.field_id)
+            tags = self.model.objects.values_list('pk', self.field_id)
         tags = tags.filter(**{self.field_id + '__isnull': False}).distinct()
         tag_dict = {}
         for t in tags:
@@ -284,7 +284,7 @@ class ManyToManyColumn(DatatableColumn):
         all_results['m2m' + self.column_name] = tag_dict
 
     def row_result(self, data_dict, page_results):
-        return page_results['m2m' + self.column_name].get(data_dict['id'], [])
+        return page_results['m2m' + self.column_name].get(data_dict['id'], self.blank)
 
     def __init__(self, *,  html=' %1% ', **kwargs):
         if not self.initialise(locals()):
@@ -296,14 +296,20 @@ class ManyToManyColumn(DatatableColumn):
         connecting_field = self.model._meta.get_field(fields[-2])
         self.related_model = connecting_field.related_model
         if hasattr(connecting_field, 'field'):
-            self.field_id = connecting_field.field.attname + '__id'
+            self.field_id = connecting_field.field.attname + '__pk'
             self.reverse = True
         else:
-            self.field_id = fields[-2] + '__id'
+            self.field_id = fields[-2] + '__pk'
             self.reverse = False
         self.field = None
-        self.options['lookup'] = list(self.related_model.objects.values_list('id', fields[-1]))
+        self.options['lookup'] = kwargs.pop('lookup', list(self.related_model.objects.values_list('pk', fields[-1])))
+        if 'blank' in kwargs:
+            self.options['lookup'].append((-1, kwargs.pop('blank')))
+            self.blank = [-1]
+        else:
+            self.blank = []
         self.options['render'] = [{'var': '%1%', 'html': html, 'function': 'ReplaceLookup'}]
+        self.setup_kwargs(kwargs)
 
 
 class DateColumn(ColumnBase):
@@ -383,3 +389,17 @@ class GroupedColumn(DatatableColumn):
 
     def row_result(self, data, page_data):
         return page_data[self.page_key].get(data[self.field])
+
+
+class CallableColumn(DatatableColumn):
+
+    def row_result(self, data_dict, _page_results):
+        fake_object = type('fake', (), {k[len(self.model_path):]: v
+                                        for k,v in data_dict.items()
+                                        if k.startswith(self.model_path)})
+        return self.object_function(fake_object)
+
+    def setup_kwargs(self, kwargs):
+        super().setup_kwargs(kwargs)
+        self.object_function = getattr(self.model, self.field[len(self.model_path):])
+        self.field = kwargs.get('parameters')
